@@ -93,7 +93,7 @@ class URLChooser:
 
     def __init__(self, extractedurls, compact=False, reverse=False, nohelp=False, dedupe=False,
                  shorten=True, run="", runsafe="", single=False, pipe=False,
-                 genconf=False, width=0):
+                 genconf=False, width=0, whitespaceoff=False):
         self.conf = expanduser("~/.config/urlscan/config.json")
         self.keys = {'/': self._search_key,
                      '0': self._digits,
@@ -145,7 +145,17 @@ class URLChooser:
                ('urlref:number', 'white', 'black', 'standout'),
                ('urlref:url', 'white', 'black', 'standout'),
                ('url:sel', 'black', 'light gray', 'bold')]
-        self.palettes.update([("default", default), ("bw", blw)])
+        # Boruch's colorized palette
+        colorized =[('header','brown','black','standout'),
+                    ('footer','white','dark red','standout'),
+                    ('search','white','dark green','standout'),
+                    ('msgtext','light cyan','black'),
+                    ('msgtext:ellipses','light gray','black'),
+                    ('urlref:number:braces','light gray','black'),
+                    ('urlref:number','yellow','black','standout'),
+                    ('urlref:url','dark green','black','standout'),
+                    ('url:sel','white','black','')]
+        self.palettes.update([("default", default), ("bw", blw), ("colorized", colorized)])
         if genconf is True:
             self._config_create()
         try:
@@ -188,6 +198,7 @@ class URLChooser:
         self.enter = False
         self.term_width, _ = urwid.raw_display.Screen().get_cols_rows()
         self.width = min(self.term_width, width or self.term_width)
+        self.whitespaceoff = whitespaceoff
         self.activate_keys = [i for i, j in urwid.Button._command_map._command.items()
                               if j == 'activate']
         self.items, self.urls = self.process_urls(extractedurls,
@@ -341,27 +352,31 @@ class URLChooser:
                                   '_digits'])
             help_men = "KEYBINDINGS\n" + help_men + "\n<0-9> - Jump to item"
             docs = ("OPTIONS\n"
-                    "all_escape -- toggle unescape all URLs\n"
-                    "all_shorten -- toggle shorten all URLs\n"
-                    "bottom -- move cursor to last item\n"
-                    "clear_screen -- redraw screen\n"
-                    "clipboard -- copy highlighted URL to clipboard using xsel/xclip\n"
-                    "clipboard_pri -- copy highlighted URL to primary selection using xsel/xclip\n"
+                    "all_escape    -- toggle unescape all URLs\n"
+                    "all_shorten   -- toggle shorten all URLs\n"
+                    "bottom        -- move cursor to last item\n"
+                    "clear_screen  -- redraw screen\n"
+                    "clipboard     -- copy highlighted URL to clipboard\n"
+                    "                 using xsel/xclip\n"
+                    "clipboard_pri -- copy highlighted URL to primary\n"
+                    "                 selection using xsel/xclip\n"
                     "config_create -- create ~/.config/urlscan/config.json\n"
-                    "context -- show/hide context\n"
-                    "down -- cursor down\n"
-                    "help_menu -- show/hide help menu\n"
-                    "link_handler -- cycle through xdg-open, webbrowser and user-defined function\n"
-                    "open_url -- open selected URL\n"
-                    "palette -- cycle through palettes\n"
-                    "quit -- quit\n"
-                    "reverse -- reverse order URLs/context\n"
-                    "shorten -- toggle shorten highlighted URL\n"
-                    "single -- quit urlscan after opening a single link\n"
-                    "top -- move to first list item\n"
-                    "up -- cursor up\n")
+                    "context       -- show/hide context\n"
+                    "down          -- cursor down\n"
+                    "help_menu     -- show/hide help menu\n"
+                    "link_handler  -- cycle through xdg-open, webbrowser \n"
+                    "                 and user-defined function\n"
+                    "open_url      -- open selected URL\n"
+                    "palette       -- cycle through palettes\n"
+                    "quit          -- quit\n"
+                    "reverse       -- reverse order URLs/context\n"
+                    "shorten       -- toggle shorten highlighted URL\n"
+                    "single        -- quit urlscan after opening a\n"
+                    "                 single link\n"
+                    "top           -- move to first list item\n"
+                    "up            -- cursor up\n")
             self.top.base_widget.body = \
-                urwid.ListBox(urwid.SimpleListWalker([urwid.Columns([(30, urwid.Text(help_men)),
+                urwid.ListBox(urwid.SimpleListWalker([urwid.Columns([(24, urwid.Text(help_men)),
                                                                      urwid.Text(docs)])]))
         else:
             self.top.base_widget.body = urwid.ListBox(self.items)
@@ -663,7 +678,7 @@ class URLChooser:
                     self.search = False
                     self.enter = False
             elif self.link_open_modes[0] == "Web Browser":
-                webbrowser.open(url.replace('&', '\&'))
+                webbrowser.open(url)
             elif self.link_open_modes[0] == "Xdg-Open":
                 run = 'xdg-open "{}"'.format(url)
                 process = Popen(shlex.split(run), stdout=PIPE, stdin=PIPE)
@@ -707,7 +722,7 @@ class URLChooser:
                     continue
             groupurls = []
             markup = []
-            if not usedfirst:
+            if not usedfirst and not self.whitespaceoff:
                 markup.append(('msgtext:ellipses', '...\n'))
             for chunks in group:
                 i = 0
@@ -736,8 +751,9 @@ class URLChooser:
                                    ('urlref:number:braces', ' ['),
                                    ('urlref:number', repr(url_idx)),
                                    ('urlref:number:braces', ']')]
-                markup += '\n'
-            if not usedlast:
+                if not self.whitespaceoff:
+                    markup += '\n'
+            if not usedlast and not self.whitespaceoff:
                 markup += [('msgtext:ellipses', '...\n\n')]
             items.append(urwid.Text(markup))
 
